#!/bin/bash

# ============LICENSE_START=======================================================
#  Copyright (C) 2019 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o errexit
set -o pipefail

if [[ "$EXECUTION_MODE" == "offline-deployment" && "$GERRIT_PROJECT" == "infra/installer/kolla" ]]; then
  echo "Info  : Offline testing are not supported for $GERRIT_PROJECT"
  exit 0
fi

if [[ "$EXECUTION_MODE" == "offline-deployment" && "$SLAVE_LABEL" != "baremetal-deploy" ]]; then
  echo "Info  : Testing of offline deployments is not currently supported!"
  exit 0
fi

# NOTE (fdegir): delete unnecessary stuff to free up space on baremetal jumphost
sudo /bin/rm -rf /tmp/$BUILD_ARTIFACTS ~/.ara \
    /opt/test /opt/stack /httpboot /opt/engine/offline/binaries /opt/engine/offline/dib \
    /tmp/kubespray_cache > /dev/null 2>&1 || true
sudo docker images -a --format {{.ID}} | xargs -n 1 sudo docker rmi -f > /dev/null 2>&1 || true

echo "Info  : Cloning infra/test repository"
cd $HOME && /bin/rm -rf $WORKSPACE
git clone -q $TEST_REPO_URL $WORKSPACE

# NOTE (fdegir): we need to override execution mode variable coming from change.properties file
if [[ "$CI_LOOP" != "release" ]]; then
  export EXECUTION_MODE=$(echo "$EXECUTION_MODE" | sed 's/deployment/test/g')
else
  export EXECUTION_MODE=online-test
fi

cd $WORKSPACE/test
./test.sh -s "$STACK_TYPE" -b "$BRANCH" -c "$DEPLOY_SCENARIO" -f "$TEST_FW" -t "$TEST_SUITE" \
    -o /tmp/openrc -i /tmp/inventory.ini -y "$YARDSTICK_DISPATCHER" -v

# vim: set ts=2 sw=2 expandtab:
